==> haskell-gnutls-0.3-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gnutls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gnutls
version:                0.3
visibility:             public
id:                     gnutls-0.3-1wEyrLP348rJAMgSWwtqMc
key:                    gnutls-0.3-1wEyrLP348rJAMgSWwtqMc
license:                GPL-3.0-only
maintainer:             Stephen Paul Weber <singpolyma@singpolyma.net>
author:                 John Millikin <jmillikin@gmail.com>
stability:              experimental
homepage:               https://git.singpolyma.net/haskell-gnutls
synopsis:               Bindings for GNU libgnutls
description:
    You almost certainly don'\''t want to depend on this release.

    This is a pre-alpha, almost useless release; its only purpose is to enable
    TLS support in some of my other libraries. More complete bindings for GNU TLS
    will be released at a later date.

category:               Network
abi:                    72272d2a47be63dc892e8c23204bee12
exposed:                True
exposed-modules:        Network.Protocol.TLS.GNU
hidden-modules:         Network.Protocol.TLS.GNU.Foreign
import-dirs:            /usr/lib/ghc-9.4.8/site-local/gnutls-0.3
library-dirs:           /usr/lib/ghc-9.4.8/site-local/gnutls-0.3
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/gnutls-0.3
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-gnutls
hs-libraries:           HSgnutls-0.3-1wEyrLP348rJAMgSWwtqMc
extra-libraries:        gnutls gnutls
extra-libraries-static:
    gnutls gmp unistring atomic hogweed gmp nettle tasn1 idn2 unistring
    p11-kit leancrypto

include-dirs:           /usr/include/p11-kit-1
depends:
    base-4.17.2.1 bytestring-0.11.5.3 transformers-0.5.6.2
    unexceptionalio-trans-0.5.2-7IZ0UuOxdOb911OzJi8umy

haddock-interfaces:     /usr/share/doc/haskell-gnutls/html/gnutls.haddock
haddock-html:           /usr/share/doc/haskell-gnutls/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gnutls-0.3.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gnutls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gnutls
version:                0.3.1
visibility:             public
id:                     gnutls-0.3.1-GeCONIUYfrHFLxYdcKd0Rw
key:                    gnutls-0.3.1-GeCONIUYfrHFLxYdcKd0Rw
license:                GPL-3.0-only
maintainer:             Stephen Paul Weber <singpolyma@singpolyma.net>
author:                 John Millikin <jmillikin@gmail.com>
stability:              experimental
homepage:               https://git.singpolyma.net/haskell-gnutls
synopsis:               Bindings for GNU libgnutls
description:
    You almost certainly don'\''t want to depend on this release.

    This is a pre-alpha, almost useless release; its only purpose is to enable
    TLS support in some of my other libraries. More complete bindings for GNU TLS
    will be released at a later date.

category:               Network
abi:                    e9f7a43dc03aaa7fc1ae5a237443d4f1
exposed:                True
exposed-modules:        Network.Protocol.TLS.GNU
hidden-modules:         Network.Protocol.TLS.GNU.Foreign
import-dirs:            /usr/lib/ghc-9.4.8/site-local/gnutls-0.3.1
library-dirs:           /usr/lib/ghc-9.4.8/site-local/gnutls-0.3.1
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/gnutls-0.3.1
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-gnutls
hs-libraries:           HSgnutls-0.3.1-GeCONIUYfrHFLxYdcKd0Rw
extra-libraries:        gnutls gnutls
extra-libraries-static:
    gnutls gmp unistring atomic hogweed gmp nettle tasn1 idn2 unistring
    p11-kit leancrypto

include-dirs:           /usr/include/p11-kit-1
depends:
    base-4.17.2.1 bytestring-0.11.5.3 transformers-0.5.6.2
    unexceptionalio-trans-0.5.2-7IZ0UuOxdOb911OzJi8umy

haddock-interfaces:     /usr/share/doc/haskell-gnutls/html/gnutls.haddock
haddock-html:           /usr/share/doc/haskell-gnutls/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
